"""
Global topics on the message bus.
"""

AUTH = 'EO-AUTH'
CERTS = 'EO-CERTS'
DELEGATES = 'EO-DELEGATES'
KEYS = 'EO-KEYS'
MEASUREMENTS = 'EO-MEASUREMENTS'
MEASUREMENTS_COMMANDS = 'EO-MEASUREMENTS-COMMANDS'
METERINGPOINTS = 'EO-METERINGPOINTS'
METERINGPOINTS_COMMANDS = 'EO-METERINGPOINTS_COMMANDS'
TECHNOLOGIES = 'EO-TECHNOLOGIES'
USERS = 'EO-USERS'
